document.addEventListener('DOMContentLoaded', function() {
  const newsFeed = document.getElementById('news-feed');
  const loadingSpinner = document.querySelector('.loading-spinner');

  async function fetchNews() {
    try {
      // Note: In a real implementation, you'd need a backend proxy to handle CORS
      // and API keys. This is a simplified example.
      const response = await fetch('https://news.google.com/rss/search?q=us+politics&hl=en-US&gl=US&ceid=US:en');
      const data = await response.text();
      const parser = new DOMParser();
      const xml = parser.parseFromString(data, 'text/xml');
      const items = xml.querySelectorAll('item');
      
      loadingSpinner.style.display = 'none';
      
      items.forEach(item => {
        const title = item.querySelector('title').textContent;
        const link = item.querySelector('link').textContent;
        const pubDate = new Date(item.querySelector('pubDate').textContent);
        
        const newsItem = document.createElement('article');
        newsItem.classList.add('news-item');
        newsItem.innerHTML = `
          <h2><a href="${link}" target="_blank" rel="noopener noreferrer">${title}</a></h2>
          <p>${pubDate.toLocaleDateString('en-US', {
            weekday: 'long',
            year: 'numeric',
            month: 'long',
            day: 'numeric'
          })}</p>
        `;
        
        newsFeed.appendChild(newsItem);
      });
    } catch (error) {
      loadingSpinner.style.display = 'none';
      newsFeed.innerHTML = '<p>Error loading news. Please try again later.</p>';
      console.error('Error fetching news:', error);
    }
  }

  fetchNews();
});
